summaryrefslogtreecommitdiffstats
path: root/core/java
diff options
context:
space:
mode:
authorSvetoslav Ganov <svetoslavganov@google.com>2013-09-03 07:24:57 +0000
committerAndroid (Google) Code Review <android-gerrit@google.com>2013-09-03 07:24:57 +0000
commit96661c42d0643c129fed60678aa0b8f99d32b456 (patch)
tree9c4923617cd20a9e3443b9c4e62ae5ae13a6f721 /core/java
parent118cb0353f6dabce1a1d6b550f7fc9eb78c7de87 (diff)
parent6bd20bc46c762860cac852888df5adf718f2be24 (diff)
downloadframeworks_base-96661c42d0643c129fed60678aa0b8f99d32b456.zip
frameworks_base-96661c42d0643c129fed60678aa0b8f99d32b456.tar.gz
frameworks_base-96661c42d0643c129fed60678aa0b8f99d32b456.tar.bz2
Merge "System print service enabled after every system reboot" into klp-dev
Diffstat (limited to 'core/java')
-rw-r--r--core/java/android/provider/Settings.java11
1 files changed, 10 insertions, 1 deletions
diff --git a/core/java/android/provider/Settings.java b/core/java/android/provider/Settings.java
index 31817cc..83e1544 100644
--- a/core/java/android/provider/Settings.java
+++ b/core/java/android/provider/Settings.java
@@ -3708,13 +3708,22 @@ public final class Settings {
public static final String LONG_PRESS_TIMEOUT = "long_press_timeout";
/**
* List of the enabled print providers.
* @hide
*/
public static final String ENABLED_PRINT_SERVICES =
"enabled_print_services";
/**
+ * List of the system print services we enabled on first boot. On
+ * first boot we enable all system, i.e. bundled print services,
+ * once, so they work out-of-the-box.
+ * @hide
+ */
+ public static final String ENABLED_ON_FIRST_BOOT_SYSTEM_PRINT_SERVICES =
+ "enabled_on_first_boot_system_print_services";
+
+ /**
* Setting to always use the default text-to-speech settings regardless
* of the application settings.
* 1 = override application settings,
@@ -3708,13 +3708,22 @@ public final class Settings {
public static final String LONG_PRESS_TIMEOUT = "long_press_timeout";
/**
- * List of the enabled print providers.
+ * List of the enabled print services.
* @hide
*/